<!--- 
	csw-accordiontextblock-generic-rh.cfm

	This 'generic' render handler render handler implements the 'getGenericFieldMappingsArray' function below to describe the available field that can be mapped.

	The logic above the function, retrieves the appropriate data and renders a textblock with accordions for the selected headings

	Note that for 'generic' render handlers the mapped data, if any, will always be passed in the following structure:
		Attributes.ElementInfo.ElementData.PropertyValues
	This is an array of one or more items, with a sub-structure named 'values'.
	Values is a structure with members as defined by the getGenericFieldMappingsArray() function.

	This generic render handler assumes these fields:
		- Textblock (required)

	Version: [2018-02-14 15:32 am]
--->

<cfscript>
	// Create the Accordion Textblock Component
	csWidget = CreateObject('component','csw-accordiontextblock');

	// load necessary resources
	csWidget.loadResources();

	// exit if all we're doing is detecting required resources
	if( Request.RenderState.RenderMode EQ "getResources" )
		exit;

	if( NOT structKeyExists(attributes,'elementinfo') )
		exit;

	// Load the Properties from the metadata form
	props = csWidget.loadProperties(Attributes.ElementInfo,Variables.Caller);

	// Make sure we have Props data
	if( NOT csWidget.hasProperties(props) )
		exit;

	// Get the element Data and Render the items
	if( StructKeyExists(Attributes.ElementInfo.ElementData, 'PropertyValues') )
		csWidget.getAndRenderItems( Attributes.ElementInfo.ElementData, props );
</cfscript>


<!--- ////////////////////////////////////////////////////////////////////////// --->
<!--- //////////////////   GENERIC RENDER HANDLER FUNCTIONS   ////////////////// --->
<!--- ////////////////////////////////////////////////////////////////////////// --->

<!---
	This is the function that is called by CommonSpot when this render handler is registred,
	allowing the user to map the fields of the source element to this render handler.

	Here we expose a structure to build describing the possible fields. Each fieldMappingArray
	item is a structure with the following 3 fields:
		- FieldName
		- Description
		- Required
--->
<cffunction name="getGenericFieldMappingsArray" returntype="array" access="private" output="no">
	<cfscript>
		var fieldMappingArray = ArrayNew(1);
		var fieldDetailsStruct = StructNew();

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Textblock';
		fieldDetailsStruct.Description = 'The text to be converted to a set of accordion panels.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		/* 
			fieldDetailsStruct = StructNew();
			fieldDetailsStruct.FieldName = 'Caption';
			fieldDetailsStruct.Description = 'The caption above the accordion panels. (Not Required)';
			fieldDetailsStruct.Required = 0;
			arrayAppend(fieldMappingArray, fieldDetailsStruct);
		*/
		return fieldMappingArray;
	</cfscript>
</cffunction>