<!--- 
	csw-accordiontextblock.cfc
	
	Version: [2018-05-29 17:15]
---> 

<cfcomponent displayname="csw-accordiontextblock" output="Yes" hint="Accordion Textblock Functions" extends="_cs_widgets._common.csw-common">

	<cffunction name="loadResources" access="public" output="Yes" returntype="void">
		<cfscript>
			Server.CommonSpot.udf.resources.loadResources("jQuery");
			Server.CommonSpot.udf.resources.loadResources("Bootstrap");
			Server.CommonSpot.udf.resources.loadResources("FontAwesome");
			Server.CommonSpot.udf.resources.loadResources("cswCommonStyles");
			Server.CommonSpot.udf.resources.loadResources("cswTextStyles");
			Server.CommonSpot.udf.resources.loadResources("cswAccordionTextblock");

			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswCommonStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswCommonStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswTextStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswTextStyles_custom");
			
			if ( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswAccordionTextblock_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswAccordionTextblock_custom");
		</cfscript>
	</cffunction>
	

	<cffunction name="loadProperties" access="public" returntype="struct" output="Yes">
		<cfargument name="elementInfo" type="struct" required="Yes">
		<cfargument name="rhCaller" type="struct" required="false" default="#StructNew()#">
		<cfargument name="showDataError" type="boolean" required="false" default="true">
		
		<cfscript>
			var widgetMetadataFormName = "CSW AccordionTextblock";
			var props = StructNew();
			var rhMetadata = arguments.ElementInfo.RenderHandlerMetaData;
			var widgetData = StructNew();
			
			
			// Check for Props and Layout Binding
			if( NOT hasPropsLayoutBinding(ElementInfo=arguments.elementInfo,metadataFormName=widgetMetadataFormName,rhCaller=arguments.rhCaller) )
				return props;

			//
			// Get Metadata (Accordion Textblock metadata)
			// ----------------------------------------------
			widgetData = rhMetadata[widgetMetadataFormName];


			props.themeClass = "";

			// Theme
			if( StructKeyExists(widgetData,"Theme") )
				props.themeClass = TRIM(widgetData.Theme);


			/********************************************/
			/********* Conversion Settings TAB **********/
			/********************************************/

			// Heading Tag Type 
			props.headingsType = getStandardField( widgetData=widgetData, field='headings', defValue='nav-tabs' );
			
			
			/***********************************************/
			/****       ACCORDION PROPERTIES TAB        ****/
			/***********************************************/

			// Panel Properties
			props.panelProperties = getFieldSettings(widgetData=widgetData, field='panelProperties' );

			// On Load Open First Panel
			props.onLoadOpenFirstPanel = getStandardField(widgetData=widgetData, field='on_load_open_first_panel', defValue='1' );
			
			// Background Colors(STRUCT)
			props.scrollToTopOffset = getDeviceSizeOptions(widgetData=widgetData, field='scroll_to_top_offset', defXSS='', defXS='', defSM='', defMD='', defLG='');
			
			
			/*********************************************/
			/****    ACCORDION HEADING PANELS TAB     ****/
			/*********************************************/

			// Heading Properties
			props.headingProperties = getFieldSettings(widgetData=widgetData, field='headingProperties' );


			/*********************************************/
			/****    ACCORDION CONTENT PANELS TAB     ****/
			/*********************************************/

			// Content Properties
			props.contentProperties = getFieldSettings(widgetData=widgetData, field='contentProperties' );
			
			// Content Properties
			props.contentMargin = getStandardField(widgetData=widgetData, field='contentMargin', defValue='20' );
			
			// Panel Background Image (STRUCT)
			props.contentBackgroundImage = getStandardMetadataImageField( widgetData=widgetData, field='Content_Background_Image', defValue='');
			
			// Panel Background Image Focal Point
			props.contentBackgroundImageFocalPoint = getStandardField( widgetData=widgetData, field='Content_BG_Image_Focal_Point', defValue='' );

			
			/*********************************/	
			/**** GENERAL PROPERTIES TAB *****/
			/*********************************/				
			
			// Element (STRUCT) (bgcolor, padding)
			props.element = getFieldSettings(widgetData=widgetData, field='Overall' );				
			
			// Background Image (STRUCT)
			props.backgroundImage = getStandardMetadataImageField( widgetData=widgetData, field='Background_Image', defValue='' );		
			
			// Background Image Focal Point
			props.backgroundImageFocalPoint = getStandardField( widgetData=widgetData, field='Background_Image_Focal_Point', defValue='' );
			
			return props;
		</cfscript>
	</cffunction>

	
	<cffunction name="getAndRenderItems" access="public" output="Yes" returntype="void">
		<cfargument name="elementDataStruct" type="struct" required="Yes">
		<cfargument name="propsStruct" type="struct" required="Yes">

		<cfscript>
			var elementData = arguments.elementDataStruct;
			var props = arguments.propsStruct;
			var elementID = request.element.id;
			var items = ArrayNew(1);
			var totalItems = 0;
			var styleAttr = '';
			var dataAttr = '';
			var contentStyleAttr = '';
			var panelTitleColor = '';
			var dKey = '';

			// Get Records from the Element as an Array of Structures
			if( StructKeyExists(elementData, 'PropertyValues') AND ArrayLen(elementData.PropertyValues) )
				items = elementData.PropertyValues;

			totalItems = ArrayLen(items);

			// Overall Element
			// -------------------
			styleAttr = '';
			if( len(props.backgroundImage) )
				styleAttr = styleAttr & "background-image: url('#props.backgroundImage#'); background-repeat: no-repeat; background-size: cover;";

			if( structKeyExists(props,'element') )
			{
				if( len(props.element.padding) )
					styleAttr = styleAttr & 'padding: #props.element.padding#;';
				if( len(props.element.bgColor) )
					styleAttr = styleAttr & 'background-color: #props.element.bgColor#;';
			}
			
			styleAttr = styleAttr & ' display: none';

			if( len(styleAttr) )
				styleAttr = 'style="#styleAttr#"';
			
			if( structKeyExists(props,'scrollToTopOffset') )
			{
				for ( dKey IN props.scrollToTopOffset ) {
					dataAttr = dataAttr & 'data-' & dKey & '-scroll-offset="' & #props.scrollToTopOffset[dKey]# & '" ';
				}
			}
			
			// Render the Accordion Widget JS 
			renderAccordionJS(propsStruct=props);
		</cfscript>

		<cfif totalItems>
			<cfoutput>
			<!--- <cfif StructKeyExists(elementData.propertyvalues[1].values,"Caption") AND LEN(TRIM(elementData.propertyvalues[1].values.Caption))>#elementData.propertyvalues[1].values.Caption#</cfif> --->
			<div id="cswAccordionTextblockWrapper-#elementID#" class="cswAccordionTextblock #props.themeClass# #props.backgroundImageFocalPoint#" #styleAttr# #dataAttr#>
				#elementData.propertyvalues[1].values.Textblock#
			</div>
			</cfoutput>
		</cfif>
	</cffunction>


	<cffunction name="renderAccordionJS" access="public" output="Yes" returntype="void">
		<cfargument name="propsStruct" type="struct" required="Yes">

		<cfscript>
			var props = arguments.propsStruct;
			var cswAccordionTextblockJS = '';
			var propsJSON = serializeJSON(props);
			var elementID = request.element.id;
		</cfscript>

		<!---
			Load Javascript required for accordions
		--->
		<cfsavecontent variable="cswAccordionTextblockJS">
		<cfoutput>
			jQuery(document).ready(function() {
				initAccordionTextblock('#elementID#','#props.headingsType#',#VAL(props.onLoadOpenFirstPanel)#,'#propsJSON#');
			});
		</cfoutput>
		</cfsavecontent>

		<cfscript>
			// Load custom javascript at the bottom of the page.
			Server.CommonSpot.udf.resources.addFooterJS(cswAccordionTextblockJS, 'TERTIARY');
		</cfscript>
	</cffunction>
	
</cfcomponent>